@@ -83,10 +83,12 @@ MakerNoteDir::createMakerNote(off_t offset,
                 offset, container, offset, "", empty_tag_names);
         }
     }
+
     // Headerless Nikon.
     if (file_type == OR_RAWFILE_TYPE_NEF) {
+        // Found on D1, D1X, D1H
         return std::make_shared<MakerNoteDir>(
-            offset, container, offset, "Nikon", mnote_nikon_tag_names);
+            offset, container, offset, "Nikon (Headerless)", mnote_nikon_tag_names);
     }
 
     if (memcmp("OLYMPUS\0", data, 8) == 0) {
