@@ -136,6 +136,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0xf94,
       { 10976,-4029,-1141,-7918,15491,2600,-1670,2071,8246 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ300),
+      0,
+      0,
+      { 8378, -2798, -769, -3068, 11410, 1877, -538, 1792, 4623 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ330),
       15,
       0,
@@ -152,6 +156,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 7906,-2709,-594,-6231,13351,3220,-1922,2631,6537 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ70),
+      0,
+      0,
+      { 11532, -4324, -1066, -2375, 10847, 1749, -564, 1699, 4351 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ100),
       143,
       0xfff,
@@ -188,6 +196,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       143,
       0xfff,
       { 7798,-2562,-740,-3879,11584,2613,-1055,2248,5434 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G6),
+      143,
+      0xfff,
+      { 8294, -2891, -651, -3869, 11590, 2595, -1183, 2267, 5352 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G10),
       0,
       0,
@@ -200,6 +212,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       15,
       0,
       { 7610, -2780, -576, -4614, 12195, 2733, -1375, 2393, 6490 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G8),
+      15,
+      0,
+      { 7610, -2780, -576, -4614, 12195, 2733, -1375, 2393, 6490 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G9),
       0,
       0,
@@ -256,6 +272,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       15,
       0,
       { 8238, -3244, -679, -3921, 11814, 2384, -836, 2022, 5852 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_LF1),
+      0,
+      0,
+      { 9379, -3267, -816, -3227, 11560, 1881, -926, 1928, 5340 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_LX1),
       0,
       0,
@@ -300,6 +320,14 @@ static const BuiltinColourMatrix s_matrices[] = {
       15,
       0,
       { 8802, -3135, -789, -3151, 11468, 1904, -550, 1745, 4810 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS40),
+      15,
+      0,
+      { 8607, -2822, -808, -3755, 11930, 2049, -820, 2060, 5224 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS50),
+      0,
+      0,
+      { 8802, -3135, -789, -3151, 11468, 1904, -550, 1745, 4810 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS60),
       15,
       0,
@@ -328,6 +356,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 9744, -3905, -779, -4899, 12807, 2324, -798, 1630, 5827 } },
+    { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS70),
+      0,
+      0,
+      { 9052, -3117, -883, -3045, 11346, 1927, -205, 1520, 4730 } },
     { OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_ZS80),
       0,
       0,
@@ -377,6 +409,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       15,
       0,
       { 7790, -2736, -755, -3452, 11870, 1769, -628, 1647, 4898 } },
+    { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_6),
+      0,
+      0,
+      { 10148, -3743, -991, -2837, 11366, 1659, -701, 1893, 4899 } },
     { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_7),
       0,
       0,
@@ -401,8 +437,10 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DMC-GX1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX1) },
     { "DMC-GX7", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX7) },
     { "DMC-GX7MK2", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX7MK2) },
+    { "DC-GX7MK3", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX7MK3) },
     { "DMC-GX8", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX8) },
     { "DMC-GX80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX80) },
+    { "DMC-GX85", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX85) },
     { "DC-GX800", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX800) },
     { "DC-GX850", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX850) },
     { "DC-GX880", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GX880) },
@@ -415,12 +453,16 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DMC-FZ150", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ150) },
     { "DMC-FZ28", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ28) },
     { "DMC-FZ30", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ30) },
+    { "DMC-FZ300", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ300) },
     { "DMC-FZ35", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ35) },
+    { "DMC-FZ38", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ38) },
     { "DMC-FZ40", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DMC_FZ40) },
     { "DMC-FZ45", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DMC_FZ45) },
     // Not the same as above
     { "DC-FZ45", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_FZ45) },
     { "DMC-FZ50", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ50) },
+    { "DMC-FZ70", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ70) },
+    { "DMC-FZ72", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ72) },
     { "DMC-FZ100", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ100) },
     { "DMC-FZ200", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ200) },
     { "DMC-FZ2500", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_FZ2500) },
@@ -433,10 +475,14 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DMC-G2", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G2) },
     { "DMC-G3", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G3) },
     { "DMC-G5", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G5) },
+    { "DMC-G6", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G6) },
     { "DMC-G7", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G7) },
+    { "DMC-G70", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G70) },
     { "DMC-G10", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G10) },
     { "DMC-G80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G80) },
+    { "DMC-G81", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G81) },
     { "DC-G9", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_G9) },
+    { "DC-G90", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G90) },
     { "DC-G91", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G91) },
     { "DC-G95", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G95) },
     { "DC-G99", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G99) },
@@ -451,7 +497,9 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DC-GH5M2", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GH5M2) },
     { "DC-GH6", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GH6) },
     { "DMC-GM1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GM1) },
+    { "DMC-GM1S", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GM1S) },
     { "DMC-GM5", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_GM5) },
+    { "DMC-LF1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_LF1) },
     { "DMC-LX1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_LX1) },
     { "DMC-LX2", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_LX2) },
     { "DMC-LX3", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_LX3) },
@@ -471,10 +519,12 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DMC-ZS60", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS60) },
     // Aliases to DMC-ZS60
     { "DMC-TZ80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ80) },
+    { "DMC-TZ81", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ81) },
     { "DMC-ZS100", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS100) },
     // Aliases to DMC-ZS100
     { "DMC-TX1", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TX1) },
     { "DMC-TZ100", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ100) },
+    { "DMC-TZ101", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ101) },
     { "DMC-TZ110", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ110) },
     { "DC-ZS200", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS200) },
     // Aliases to DMC-ZS200
@@ -482,12 +532,25 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DC-ZS80", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_ZS80) },
     // Aliases to DC-ZS80
     { "DC-TZ95", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_TZ95) },
+    { "DC-TZ96", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_TZ96) },
+
+    { "DMC-ZS40", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS40) },
+    // Aliases to DMC-ZS40
+    { "DMC-TZ60", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ60) },
+    { "DMC-TZ61", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ61) },
+
+    // Also to DMC-ZS50
+    { "DMC-TZ71", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ71) },
+
+    // Aliases to DC-ZS70
+    { "DC-TZ90", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ90) },
 
     { "DIGILUX 2", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX2) },
     { "DIGILUX 3", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX3) },
     { "D-LUX 3", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_3) },
     { "D-LUX 4", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_4) },
     { "D-LUX 5", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_5) },
+    { "D-LUX 6", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_6) },
     { "D-Lux 7", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_7) },
     { "V-LUX 1", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_VLUX_1) },
     { "D-LUX (Typ 109)", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_TYP109) },
